@@ -1,3 +1,4 @@
+import importlib
 import io
 import logging
 import os
@@ -19,24 +20,34 @@ markdown_extensions.append(".py")
 
 
 class PheasantPlugin(BasePlugin):
-    config_scheme = (("jupyter", config_options.Type(bool, default=True)),)
+    config_scheme = (
+        ("jupyter", config_options.Type(bool, default=True)),
+        ("dirty", config_options.Type(bool, default=True)),
+        ("version", config_options.Type(str, default="")),
+        ("header", config_options.Type(dict, default={})),
+    )
     converter = Pheasant()
-    converter.jupyter.verbose = 0
-    version = pheasant.__version__
     logger.info(f"[Pheasant] Converter created.")
 
-    def on_config(self, config, **kwargs):
-        if self.config:
-            self.converter.update_config(self.config)
+    def on_config(self, config):
+        self.converter.jupyter.set_config(enabled=self.config["jupyter"])
+        self.converter.header.set_config(self.config["header"])
 
-        self.converter.jupyter.enabled = self.config["jupyter"]
+        if self.config["version"]:
+            try:
+                module = importlib.import_module(self.config["version"])
+                version = module.__version__
+            except Exception:
+                version = self.config["version"]
+            config["theme"].version = version
 
         self.config["extra_css"] = list(config["extra_css"])
         self.config["extra_javascript"] = list(config["extra_javascript"])
 
         logger.info(f"[Pheasant] Converter configured.")
 
-        config["nav"] = build_nav(config["nav"], config["docs_dir"])
+        if config["nav"]:
+            config["nav"] = build_nav(config["nav"], config["docs_dir"])
         return config
 
     def on_files(self, files, config):
@@ -72,30 +83,33 @@ class PheasantPlugin(BasePlugin):
 
         return files
 
-    def on_nav(self, nav, config, **kwargs):
+    def on_nav(self, nav, config, files):
         paths = [page.file.abs_src_path for page in nav.pages]
         logger.info(f"[Pheasant] Converting {len(paths)} pages.")
         self.converter.convert_from_files(paths)
         logger.info(f"[Pheasant] Conversion finished. {self.converter.log.info}")
         return nav
 
-    def on_page_read_source(self, source, page, **kwargs):
+    def on_page_read_source(self, page, config):
         try:
             return self.converter.pages[page.file.abs_src_path].source
         except KeyError:
             return "Skipped."
 
-    def on_page_content(self, content, page, **kwargs):
+    def on_page_content(self, html, page, config, files):
+        if page.toc.items:
+            page.title = page.toc.items[0].title
         if page.file.abs_src_path not in self.converter.pages:
-            return content
+            return html
         else:
             extra = self.converter.pages[page.file.abs_src_path].meta["extra_html"]
-            return "\n".join([extra, content])
+            return "\n".join([extra, html])
 
-    def on_post_page(self, output, **kwargs):  # This is needed for holoviews.
+    def on_post_page(self, output, page, config):  # This is needed for holoviews.
         return output.replace('.js" defer></script>', '.js"></script>')
 
-    def on_serve(self, server, **kwargs):  # pragma: no cover
+    def on_serve(self, server, config):
+        self.converter.dirty = self.config["dirty"]
         watcher = server.watcher
         builder = list(watcher._tasks.values())[0]["func"]
         root = os.path.join(os.path.dirname(pheasant.__file__), "theme")
